Learn R Programming

ascribe (version 0.2.0)

ascribe-package: ascribe: Static Detection and Citation of R Package and Function Usage

Description

Scans R source files for package and function use, then builds citations from configurable package universes. Supports .R, .Rmd, and .qmd files, resolves unqualified calls by attachment order and re-export origin, and leaves each package collection to define its own citations. See 'stanflow' https://github.com/VisruthSK/stanflow for an example usage.

Arguments

Author

Maintainer: Visruth Srimath Kandali public@visruth.com (ORCID) [copyright holder]

Authors:

See Also